@@ -10,7 +10,7 @@ from quantecon.game_theory.mclennan_tourky import (
 
 
 class TestMclennanTourky():
-    def setup(self):
+    def setup_method(self):
         def anti_coordination(N, v):
             payoff_array = np.empty((2,)*N)
             payoff_array[0, :] = 1
@@ -56,7 +56,7 @@ class TestMclennanTourky():
 
 
 class TestMclennanTourkyInvalidInputs():
-    def setup(self):
+    def setup_method(self):
             self.bimatrix = [[(3, 3), (3, 2)],
                              [(2, 2), (5, 6)],
                              [(0, 3), (6, 1)]]
@@ -73,7 +73,7 @@ class TestMclennanTourkyInvalidInputs():
 
 
 class TestEpsilonNash():
-    def setup(self):
+    def setup_method(self):
         def anti_coordination(N, v):
             payoff_array = np.empty((2,)*N)
             payoff_array[0, :] = 1
