@@ -14,7 +14,7 @@ import math
 import numpy as np
 import scipy.linalg as la
 from numba import jit, vectorize
-from .ce_util import ckron, gridmake
+from ._ce_util import ckron, gridmake
 from .util import check_random_state
 
 __all__ = ['qnwcheb', 'qnwequi', 'qnwlege', 'qnwnorm', 'qnwlogn',
@@ -24,11 +24,37 @@ __all__ = ['qnwcheb', 'qnwequi', 'qnwlege', 'qnwnorm', 'qnwlogn',
 
 @vectorize(nopython=True)
 def gammaln(x):
+    """
+    Natural logarithm of the gamma function.
+    
+    Parameters
+    ----------
+    x : float
+        Input value.
+        
+    Returns
+    -------
+    float
+        Natural logarithm of gamma(x).
+    """
     return math.lgamma(x)
 
 
 @vectorize(nopython=True)
 def fix(x):
+    """
+    Round towards zero.
+    
+    Parameters
+    ----------
+    x : float
+        Input value.
+        
+    Returns
+    -------
+    float
+        Rounded value towards zero.
+    """
     if x < 0:
         return math.ceil(x)
     else:
@@ -113,11 +139,12 @@ def qnwequi(n, a, b, kind="N", equidist_pp=None, random_state=None):
     equidist_pp : array_like, optional(default=None)
         TODO: I don't know what this does
 
-    random_state : int or np.random.RandomState, optional
-        Random seed (integer) or np.random.RandomState instance to set
-        the initial state of the random number generator for
-        reproducibility. If None, a randomly initialized RandomState is
-        used.
+    random_state : int or np.random.RandomState/Generator, optional
+        Random seed (integer) or np.random.RandomState or Generator
+        instance to set the initial state of the random number
+        generator for reproducibility. If None, a randomly
+        initialized RandomState is used. Relevant only when setting
+        `kind='R'`.
 
     Returns
     -------
@@ -171,7 +198,7 @@ def qnwequi(n, a, b, kind="N", equidist_pp=None, random_state=None):
         nodes = np.outer(i * (i+1) / 2, j)
         nodes = (nodes - fix(nodes)).squeeze()
     elif kind.upper() == "R":  # pseudo-random
-        nodes = random_state.rand(n, d).squeeze()
+        nodes = random_state.random((n, d)).squeeze()
     else:
         raise ValueError("Unknown sequence requested")
 
@@ -241,6 +268,9 @@ def qnwnorm(n, mu=None, sig2=None, usesqrtm=False):
     sig2 : array_like(float), optional(default=eye(d))
         A d x d array representing the variance-covariance matrix of the
         multivariate normal distribution.
+    
+    usesqrtm : bool, optional(default=False)
+        Whether to use matrix square root method for decomposition.
 
     Returns
     -------
@@ -294,8 +324,8 @@ def qnwnorm(n, mu=None, sig2=None, usesqrtm=False):
         new_sig2 = la.cholesky(sig2)
 
     if d > 1:
-        nodes = nodes.dot(new_sig2) + mu  # Broadcast ok
-    else:  # nodes.dot(sig) will not be aligned in scalar case.
+        nodes = nodes @ new_sig2 + mu  # Broadcast ok
+    else:  # nodes @ new_sig2 will not be aligned in scalar case.
         nodes = nodes * new_sig2 + mu
 
     return nodes.squeeze(), weights
@@ -469,7 +499,7 @@ def qnwunif(n, a, b):
     return nodes, weights
 
 
-def quadrect(f, n, a, b, kind='lege', *args, **kwargs):
+def quadrect(f, n, a, b, kind='lege', random_state=None, *args, **kwargs):
     """
     Integrate the d-dimensional function f on a rectangle with lower and
     upper bound for dimension i defined by a[i] and b[i], respectively;
@@ -510,6 +540,12 @@ def quadrect(f, n, a, b, kind='lege', *args, **kwargs):
         H    - Haber  equidistributed sequence
         R    - Monte Carlo
 
+    random_state : int or np.random.RandomState/Generator, optional
+        Random seed (integer) or np.random.RandomState or Generator
+        instance to set the initial state of the random number generator
+        for reproducibility. If None, a randomly initialized RandomState
+        is used. Relevant only when setting `kind='R'`.
+
     *args, **kwargs :
         Other arguments passed to the function f
 
@@ -538,9 +574,9 @@ def quadrect(f, n, a, b, kind='lege', *args, **kwargs):
     elif kind.lower() == "simp":
         nodes, weights = qnwsimp(n, a, b)
     else:
-        nodes, weights = qnwequi(n, a, b, kind)
+        nodes, weights = qnwequi(n, a, b, kind, random_state=random_state)
 
-    out = weights.dot(f(nodes, *args, **kwargs))
+    out = weights @ f(nodes, *args, **kwargs)
     return out
 
 
